@@ -259,6 +259,15 @@ pub async fn execute(info: &EarlyInfo) -> Result<()> {
             .display_order(1)
             .help("Don't do anything except write changelogs")
         )
+        .arg(
+          Arg::with_name("locktags")
+            .short("l")
+            .long("lock-tags")
+            .takes_value(false)
+            .conflicts_with_all(&["pause", "resume", "abort"])
+            .display_order(1)
+            .help("Don't forward project tags")
+        )
         .display_order(1)
     )
     .subcommand(
@@ -428,8 +437,8 @@ async fn parse_matches(m: ArgMatches<'_>, early_info: &EarlyInfo) -> Result<()>
     ("show", Some(m)) => show(pref_vcs, m.is_present("wide"), m.is_present("prev"), ignore_current)?,
     ("set", Some(m)) => set(pref_vcs, m.value_of("id"), m.value_of("name"), m.value_of("value").unwrap())?,
     ("diff", Some(_)) => diff(pref_vcs, ignore_current)?,
-    ("files", Some(_)) => files(pref_vcs, ignore_current)?,
-    ("changes", Some(_)) => changes(pref_vcs, ignore_current)?,
+    ("files", Some(_)) => files(pref_vcs, ignore_current).await?,
+    ("changes", Some(_)) => changes(pref_vcs, ignore_current).await?,
     ("plan", Some(m)) => plan(early_info, pref_vcs, m.value_of("id"), m.value_of("template"), ignore_current).await?,
     ("release", Some(m)) if m.is_present("abort") => abort()?,
     ("release", Some(m)) if m.is_present("resume") => resume(pref_vcs)?,
@@ -442,7 +451,7 @@ async fn parse_matches(m: ArgMatches<'_>, early_info: &EarlyInfo) -> Result<()>
         Engagement::Full
       };
 
-      release(pref_vcs, m.is_present("all"), &dry, m.is_present("pause")).await?
+      release(pref_vcs, m.is_present("all"), &dry, m.is_present("locktags"), m.is_present("pause")).await?
     }
     ("init", Some(m)) => init(m.value_of("maxdepth").map(|d| d.parse().unwrap()).unwrap_or(5))?,
     ("info", Some(m)) => {
