@@ -3,11 +3,12 @@
 mod cli;
 
 use env_logger::{Builder, Env};
+use tokio::runtime::Runtime;
 use versio::commands::early_info;
 use versio::errors::Result;
 
 fn main() {
-  if let Err(e) = run() {
+  if let Err(e) = Runtime::new().unwrap().block_on(run()) {
     use std::io::Write;
     let stderr = &mut std::io::stderr();
     let errmsg = "Error writing to stderr.";
@@ -27,11 +28,11 @@ fn main() {
   }
 }
 
-fn run() -> Result<()> {
+async fn run() -> Result<()> {
   // This is even better than `env_logger::try_init()?`.
   Builder::from_env(Env::new().default_filter_or("versio=warn")).try_init()?;
 
   let info = early_info()?;
   std::env::set_current_dir(info.working_dir())?;
-  cli::execute(&info)
+  cli::execute(&info).await
 }
