@@ -13,7 +13,7 @@ use error_chain::bail;
 use log::trace;
 use serde::Deserialize;
 use std::cmp::{max, Ordering};
-use std::collections::{HashMap, HashSet, VecDeque};
+use std::collections::{BTreeSet, HashMap, HashSet, VecDeque};
 use std::iter::{empty, once};
 use std::path::{Path, PathBuf};
 
@@ -158,8 +158,8 @@ impl Mono {
     Ok(())
   }
 
-  pub fn keyed_files(&self) -> Result<impl Iterator<Item = Result<(String, String)>> + '_> {
-    let changes = self.changes()?;
+  pub async fn keyed_files(&self) -> Result<impl Iterator<Item = Result<(String, String)>> + '_> {
+    let changes = self.changes().await?;
     let prs = changes.into_groups().into_iter().map(|(_, v)| v).filter(|pr| !pr.best_guess());
 
     let mut vec = Vec::new();
@@ -170,11 +170,11 @@ impl Mono {
     Ok(vec.into_iter().flatten())
   }
 
-  pub fn build_plan(&self) -> Result<Plan> {
+  pub async fn build_plan(&self) -> Result<Plan> {
     let mut plan = PlanBuilder::create(&self.repo, self.current.file(), self.user_prefs.auth());
 
     // Consider the grouped, unsquashed commits to determine project sizing and changelogs.
-    for pr in self.changes()?.groups().values() {
+    for pr in self.changes().await?.groups().values() {
       plan.start_pr(pr)?;
       for commit in pr.included_commits() {
         plan.start_commit(commit.clone())?;
@@ -196,9 +196,9 @@ impl Mono {
     Ok(plan.build())
   }
 
-  pub fn changes(&self) -> Result<Changes> {
+  pub async fn changes(&self) -> Result<Changes> {
     let base = FromTagBuf::new(self.current.prev_tag().to_string(), true);
-    changes(&self.user_prefs.auth, &self.repo, base, "HEAD".into())
+    changes(&self.user_prefs.auth, &self.repo, base, "HEAD".into()).await
   }
 }
 
@@ -293,16 +293,34 @@ fn pr_keyed_files(repo: &Repo, pr: FullPr) -> impl Iterator<Item = Result<(Strin
   }
 }
 
+/// Additional information about a plan that doesn't contribute to plan's execution, but may still be of
+/// interested to the user.
+pub struct PlanInfo {
+  failed_commits: BTreeSet<CommitInfoBuf>
+}
+
+impl Default for PlanInfo {
+  fn default() -> PlanInfo { PlanInfo::new() }
+}
+
+impl PlanInfo {
+  pub fn new() -> PlanInfo { PlanInfo { failed_commits: BTreeSet::new() } }
+  pub fn failed_commits(&self) -> &BTreeSet<CommitInfoBuf> { &self.failed_commits }
+  pub fn add_failed_commit(&mut self, failure: CommitInfoBuf) { self.failed_commits.insert(failure); }
+}
+
 pub struct Plan {
   incrs: HashMap<ProjectId, (Size, Changelog)>, // proj ID, incr size, changelog
   ineffective: Vec<LoggedPr>,                   // PRs that didn't apply to any project
-  chain_writes: Vec<(ProjectId, ProjectId)>
+  chain_writes: Vec<(ProjectId, ProjectId)>,
+  info: PlanInfo
 }
 
 impl Plan {
   pub fn incrs(&self) -> &HashMap<ProjectId, (Size, Changelog)> { &self.incrs }
   pub fn ineffective(&self) -> &[LoggedPr] { &self.ineffective }
   pub fn chain_writes(&self) -> &[(ProjectId, ProjectId)] { &self.chain_writes }
+  pub fn info(&self) -> &PlanInfo { &self.info }
 }
 
 pub struct Changelog {
@@ -389,7 +407,8 @@ struct PlanBuilder<'s> {
   incrs: HashMap<ProjectId, (Size, Changelog)>, // proj ID, incr size, changelog
   ineffective: Vec<LoggedPr>,                   // PRs that didn't apply to any project
   github_info: Option<GithubInfo>,
-  chain_writes: Vec<(ProjectId, ProjectId)>
+  chain_writes: Vec<(ProjectId, ProjectId)>,
+  info: PlanInfo
 }
 
 impl<'s> PlanBuilder<'s> {
@@ -405,7 +424,8 @@ impl<'s> PlanBuilder<'s> {
       incrs: HashMap::new(),
       ineffective: Vec::new(),
       github_info,
-      chain_writes: Vec::new()
+      chain_writes: Vec::new(),
+      info: PlanInfo::new()
     }
   }
 
@@ -451,7 +471,6 @@ impl<'s> PlanBuilder<'s> {
     let kind = commit.kind().to_string();
     let summary = commit.summary().to_string();
     let msg = commit.message().to_string();
-    self.on_commit = Some(commit);
     self.prev.slice_to(FromTagBuf::new(id.clone(), false))?;
 
     let url = self
@@ -463,10 +482,14 @@ impl<'s> PlanBuilder<'s> {
     for (proj_id, logged_pr) in &mut self.on_pr_sizes {
       if let Some(cur_project) = self.current.get_project(proj_id) {
         let size = cur_project.size(self.current.sizes(), &kind)?;
+        if size.is_failure() {
+          self.info.add_failed_commit(commit.clone());
+        }
         logged_pr.commits.push(LoggedCommit::new(id.clone(), summary.clone(), msg.clone(), size, url.clone()));
       }
     }
 
+    self.on_commit = Some(commit);
     Ok(())
   }
 
@@ -570,7 +593,7 @@ impl<'s> PlanBuilder<'s> {
   }
 
   pub fn build(self) -> Plan {
-    Plan { incrs: self.incrs, ineffective: self.ineffective, chain_writes: self.chain_writes }
+    Plan { incrs: self.incrs, ineffective: self.ineffective, chain_writes: self.chain_writes, info: self.info }
   }
 }
 
