@@ -1,7 +1,7 @@
 //! The way we output things to the user.
 
 use crate::analyze::Analysis;
-use crate::commands::InfoShow;
+use crate::commands::{failed_hashes, InfoShow};
 use crate::config::{Project, ProjectId, Size};
 use crate::errors::{Result, ResultExt};
 use crate::github::Changes;
@@ -376,7 +376,9 @@ impl PlanOutput {
         .unwrap_or_else(|| panic!("No such project {}.", id));
 
       if let Some(prev_vers) = prev_vers {
-        if size != &Size::Empty {
+        if size.is_failure() {
+          println!("  ! Non-parseable conventional commits: {}", failed_hashes(plan));
+        } else if size != &Size::Empty {
           let target = size.apply(&prev_vers)?;
           if Size::less_than(&curt_vers, &target)? {
             if curt_proj.verify_restrictions(&target).is_err() {
@@ -506,8 +508,8 @@ impl ReleaseOutput {
     self.result.append_forward(all, name, prev, curt, targ);
   }
 
-  pub fn write_no_change(&mut self, all: bool, name: String, prev: Option<String>, curt: String) {
-    self.result.append_no_change(all, name, prev, curt);
+  pub fn write_no_change(&mut self, all: bool, locked: bool, name: String, prev: Option<String>, curt: String) {
+    self.result.append_no_change(all, locked, name, prev, curt);
   }
 
   pub fn write_new(&mut self, all: bool, name: String, curt: String) { self.result.append_new(all, name, curt); }
@@ -536,8 +538,8 @@ impl ReleaseResult {
     self.append(ReleaseEvent::Forward(all, name, prev, curt, targ));
   }
 
-  fn append_no_change(&mut self, all: bool, name: String, prev: Option<String>, curt: String) {
-    self.append(ReleaseEvent::NoChange(all, name, prev, curt));
+  fn append_no_change(&mut self, all: bool, locked: bool, name: String, prev: Option<String>, curt: String) {
+    self.append(ReleaseEvent::NoChange(all, locked, name, prev, curt));
   }
 
   fn append_new(&mut self, all: bool, name: String, curt: String) { self.append(ReleaseEvent::New(all, name, curt)); }
@@ -582,7 +584,7 @@ enum ReleaseEvent {
   Logged(PathBuf),
   Changed(String, String, String, String),
   Forward(bool, String, String, String, String),
-  NoChange(bool, String, Option<String>, String),
+  NoChange(bool, bool, String, Option<String>, String),
   New(bool, String, String),
   Commit,
   Pause,
@@ -607,16 +609,17 @@ impl ReleaseEvent {
           println!("  {} : {} -> {} instead of {}", name, prev, targ, curt);
         }
       }
-      ReleaseEvent::NoChange(all, name, prev, curt) => {
+      ReleaseEvent::NoChange(all, locked, name, prev, curt) => {
         if *all {
+          let lockmsg = if *locked { " (locked)" } else { "" };
           if let Some(prev) = prev {
             if prev == curt {
-              println!("  {} : untouched at {}", name, curt);
+              println!("  {} : untouched at {}{}", name, curt, lockmsg);
             } else {
-              println!("  {} : untouched: {} -> {}", name, prev, curt);
+              println!("  {} : untouched: {} -> {}{}", name, prev, curt, lockmsg);
             }
           } else {
-            println!("  {} : untouched non-existent at {}", name, curt);
+            println!("  {} : untouched non-existent at {}{}", name, curt, lockmsg);
           }
         }
       }
